@@ -1,16 +1,21 @@
 //! Handle `--git` and related flags
 
+use std::path::{Path, PathBuf};
+use std::{io, ops::Sub, thread::sleep, time::Duration};
+
+use anyhow::Result;
+use git2::{build::RepoBuilder, FetchOptions, ProxyOptions, Repository, RepositoryInitOptions};
+use remove_dir_all::remove_dir_all;
+
+pub use utils::clone_git_template_into_temp;
+
+use crate::warn;
+
 mod creds;
 mod gitconfig;
 mod identity_path;
 mod utils;
 
-use anyhow::Result;
-use std::path::{Path, PathBuf};
-
-use git2::{build::RepoBuilder, FetchOptions, ProxyOptions, Repository, RepositoryInitOptions};
-pub use utils::clone_git_template_into_temp;
-
 // cargo-generate (as application) whant from git module:
 // 1. cloning remote
 // 2. initialize freshly generated template
@@ -23,7 +28,7 @@ pub use utils::clone_git_template_into_temp;
 // * if `<url>` is the local path on system the clone should also be done the same way as `git clone` there is `--path`
 //    for different behavior
 
-// basicly we want to call:
+// basically we want to call:
 // git clone --recurse-submodules --depth 1 --branch <branch> <url> <tmp_dir>
 
 /// Default branch to use if not specified but required
@@ -84,8 +89,34 @@ impl<'cb> RepoCloneBuilder<'cb> {
     }
 
     fn clone(mut self, dest_path: &Path) -> Result<Repository> {
-        if let Some(callbacks) = crate::git::creds::git_ssh_credentials_callback(self.identity)? {
-            self.fetch_options.remote_callbacks(callbacks);
+        #[cfg(not(windows))]
+        {
+            if self.identity.is_some() {
+                if let Some(callbacks) = creds::git_ssh_credentials_callback(self.identity)? {
+                    self.fetch_options.remote_callbacks(callbacks);
+                } else {
+                    self.fetch_options
+                        .remote_callbacks(creds::git_ssh_agent_callback());
+                }
+            } else {
+                self.fetch_options
+                    .remote_callbacks(creds::git_ssh_agent_callback());
+            }
+        }
+        #[cfg(windows)]
+        {
+            use crate::info;
+            use console::style;
+
+            if self.identity.is_some() {
+                info!(
+                    "{} {}",
+                    style("HEADS UP!").bold(),
+                    style("The `--identity` argument is not supported on windows, trying to use ssh-agent instead.").bold().yellow(),
+                );
+            }
+            self.fetch_options
+                .remote_callbacks(creds::git_ssh_agent_callback());
         }
         self.builder.fetch_options(self.fetch_options);
         self.builder
@@ -128,10 +159,6 @@ pub fn init(project_dir: &Path, branch: &str, force: bool) -> Git2Result<Reposit
     }
 }
 
-use crate::warn;
-use remove_dir_all::remove_dir_all;
-use std::{io, ops::Sub, thread::sleep, time::Duration};
-
 /// remove context of repository by removing `.git` from filesystem
 pub fn remove_history(project_dir: &Path) -> io::Result<()> {
     let git_dir = project_dir.join(".git");
