@@ -9,12 +9,15 @@ use crate::config;
 use crate::emoji;
 
 mod file_mod;
+mod system_mod;
 mod variable_mod;
 
+type HookResult<T> = std::result::Result<T, Box<EvalAltResult>>;
+
 struct CleanupJob<F: FnOnce()>(Option<F>);
 
 impl<F: FnOnce()> CleanupJob<F> {
-    pub fn new(f: F) -> Self {
+    pub const fn new(f: F) -> Self {
         Self(Some(f))
     }
 }
@@ -29,8 +32,10 @@ pub fn execute_pre_hooks(
     dir: &Path,
     liquid_object: Rc<RefCell<liquid::Object>>,
     template_cfg: &mut config::Config,
+    allow_commands: bool,
+    silent: bool,
 ) -> Result<()> {
-    let engine = create_rhai_engine(dir, liquid_object);
+    let engine = create_rhai_engine(dir, liquid_object, allow_commands, silent);
     evaluate_scripts(dir, &template_cfg.get_pre_hooks(), engine)
 }
 
@@ -38,8 +43,10 @@ pub fn execute_post_hooks(
     dir: &Path,
     liquid_object: Rc<RefCell<liquid::Object>>,
     template_cfg: &config::Config,
+    allow_commands: bool,
+    silent: bool,
 ) -> Result<()> {
-    let engine = create_rhai_engine(dir, liquid_object);
+    let engine = create_rhai_engine(dir, liquid_object, allow_commands, silent);
     evaluate_scripts(dir, &template_cfg.get_post_hooks(), engine)
 }
 
@@ -65,7 +72,12 @@ fn evaluate_scripts(dir: &Path, scripts: &[String], engine: rhai::Engine) -> Res
     Ok(())
 }
 
-fn create_rhai_engine(dir: &Path, liquid_object: Rc<RefCell<liquid::Object>>) -> rhai::Engine {
+fn create_rhai_engine(
+    dir: &Path,
+    liquid_object: Rc<RefCell<liquid::Object>>,
+    allow_commands: bool,
+    silent: bool,
+) -> rhai::Engine {
     let mut engine = rhai::Engine::new();
 
     let module = variable_mod::create_module(liquid_object);
@@ -74,10 +86,12 @@ fn create_rhai_engine(dir: &Path, liquid_object: Rc<RefCell<liquid::Object>>) ->
     let module = file_mod::create_module(dir);
     engine.register_static_module("file", module.into());
 
-    engine.register_result_fn(
-        "abort",
-        |error: &str| -> Result<String, Box<EvalAltResult>> { Err(error.into()) },
-    );
+    let module = system_mod::create_module(allow_commands, silent);
+    engine.register_static_module("system", module.into());
+
+    engine.register_result_fn("abort", |error: &str| -> HookResult<String> {
+        Err(error.into())
+    });
 
     engine
 }
