@@ -53,6 +53,7 @@ use ignore_me::remove_dir_files;
 use interactive::prompt_for_variable;
 use liquid::ValueView;
 use project_variables::{StringEntry, TemplateSlots, VarInfo};
+use std::ffi::OsString;
 use std::{
     borrow::Borrow,
     cell::RefCell,
@@ -73,7 +74,7 @@ use crate::{
 };
 
 /// # Panics
-pub fn generate(mut args: Args) -> Result<()> {
+pub fn generate(mut args: GenerateArgs) -> Result<()> {
     let app_config: AppConfig = app_config_path(&args.config)?.as_path().try_into()?;
 
     if args.list_favorites {
@@ -107,8 +108,16 @@ pub fn generate(mut args: Args) -> Result<()> {
 
     check_cargo_generate_version(&template_config)?;
 
+    let base_dir = env::current_dir()?;
     let project_name = resolve_project_name(&args)?;
-    let project_dir = resolve_project_dir(&project_name, &args)?;
+    let project_dir = resolve_project_dir(&base_dir, &project_name, &args)?;
+
+    println!(
+        "{} {} {}",
+        emoji::WRENCH,
+        style(format!("Basedir: {}", base_dir.display())).bold(),
+        style("...").bold()
+    );
 
     println!(
         "{} {} {}",
@@ -118,6 +127,7 @@ pub fn generate(mut args: Args) -> Result<()> {
     );
 
     expand_template(
+        &project_dir,
         &project_name,
         &template_folder,
         source_template.template_values(),
@@ -180,7 +190,7 @@ fn get_source_template_into_temp(
     Ok((temp_dir, branch))
 }
 
-fn resolve_project_name(args: &Args) -> Result<ProjectName> {
+fn resolve_project_name(args: &GenerateArgs) -> Result<ProjectName> {
     match args.name {
         Some(ref n) => Ok(ProjectName::new(n)),
         None if !args.silent => Ok(ProjectName::new(interactive::name()?)),
@@ -280,12 +290,15 @@ pub(crate) fn copy_dir_all(src: impl AsRef<Path>, dst: impl AsRef<Path>) -> Resu
 
         for src_entry in fs::read_dir(src)? {
             let src_entry = src_entry?;
-            let dst_path = dst.as_ref().join(src_entry.file_name());
+            let filename = src_entry.file_name().to_string_lossy().to_string();
             let entry_type = src_entry.file_type()?;
 
             if entry_type.is_dir() {
+                let dst_path = dst.as_ref().join(filename);
                 check_dir_all(src_entry.path(), dst_path)?;
             } else if entry_type.is_file() {
+                let filename = filename.strip_suffix(".liquid").unwrap_or(&filename);
+                let dst_path = dst.as_ref().join(filename);
                 if dst_path.exists() {
                     bail!(
                         "{} {} {}",
@@ -306,13 +319,20 @@ pub(crate) fn copy_dir_all(src: impl AsRef<Path>, dst: impl AsRef<Path>) -> Resu
     }
     fn copy_all(src: impl AsRef<Path>, dst: impl AsRef<Path>) -> Result<()> {
         fs::create_dir_all(&dst)?;
+        let git_file_name: OsString = ".git".into();
         for src_entry in fs::read_dir(src)? {
             let src_entry = src_entry?;
-            let dst_path = dst.as_ref().join(src_entry.file_name());
+            let filename = src_entry.file_name().to_string_lossy().to_string();
             let entry_type = src_entry.file_type()?;
             if entry_type.is_dir() {
+                let dst_path = dst.as_ref().join(filename);
+                if git_file_name == src_entry.file_name() {
+                    continue;
+                }
                 copy_dir_all(src_entry.path(), dst_path)?;
             } else if entry_type.is_file() {
+                let filename = filename.strip_suffix(".liquid").unwrap_or(&filename);
+                let dst_path = dst.as_ref().join(filename);
                 fs::copy(src_entry.path(), dst_path)?;
             }
         }
@@ -345,44 +365,55 @@ fn locate_template_file(
     }
 }
 
-fn resolve_project_dir(name: &ProjectName, args: &Args) -> Result<PathBuf> {
+/// Resolves the project dir.
+///
+/// if `args.init == true` it returns the path of `$CWD` and if let some `args.destination`,
+/// it returns the given path.
+fn resolve_project_dir(
+    base_dir: &Path,
+    name: &ProjectName,
+    args: &GenerateArgs,
+) -> Result<PathBuf> {
     if args.init {
-        let cwd = env::current_dir()?;
-        return Ok(cwd);
+        return Ok(base_dir.into());
     }
 
-    let dir_name = if args.force {
-        name.raw()
-    } else {
+    let base_path = args
+        .destination
+        .as_ref()
+        .map(|p| p.to_path_buf())
+        .unwrap_or_else(|| env::current_dir().unwrap_or_else(|_| ".".into()));
+
+    let dir_name = args.force.then(|| name.raw()).unwrap_or_else(|| {
         rename_warning(name);
         name.kebab_case()
-    };
-    let project_dir = env::current_dir()
-        .unwrap_or_else(|_e| ".".into())
-        .join(&dir_name);
+    });
+
+    let project_dir = base_path.join(&dir_name);
 
     if project_dir.exists() {
-        Err(anyhow!(
+        bail!(
             "{} {}",
             emoji::ERROR,
             style("Target directory already exists, aborting!")
                 .bold()
                 .red()
-        ))
-    } else {
-        Ok(project_dir)
+        );
     }
+
+    Ok(project_dir)
 }
 
 fn expand_template(
+    project_dir: &Path,
     name: &ProjectName,
     dir: &Path,
     template_values: &HashMap<String, toml::Value>,
     mut template_config: Config,
-    args: &Args,
+    args: &GenerateArgs,
 ) -> Result<()> {
     let crate_type: CrateType = args.into();
-    let liquid_object = template::create_liquid_object(name, &crate_type, args.force)?;
+    let liquid_object = template::create_liquid_object(project_dir, name, &crate_type, args.force)?;
     let liquid_object =
         project_variables::fill_project_variables(liquid_object, &template_config, |slot| {
             let provided_value = template_values.get(&slot.var_name).and_then(|v| v.as_str());
@@ -422,6 +453,7 @@ fn expand_template(
         &all_hook_files,
         &mut pbar,
     )?;
+    pbar.join().unwrap();
 
     execute_post_hooks(
         dir,
@@ -432,8 +464,6 @@ fn expand_template(
     )?;
     remove_dir_files(all_hook_files, false);
 
-    pbar.join().unwrap();
-
     Ok(())
 }
 
@@ -465,7 +495,7 @@ pub(crate) fn add_missing_provided_values(
 fn merge_conditionals(
     template_config: &Config,
     liquid_object: liquid::Object,
-    args: &Args,
+    args: &GenerateArgs,
 ) -> Result<(config::TemplateConfig, liquid::Object), anyhow::Error> {
     let mut template_config = (*template_config).clone();
     let mut template_cfg = template_config.template.unwrap_or_default();
